@@ -73,6 +73,7 @@ class BuilderFiQuS:
         for key, value in model_data.Options_FiQuS.cct.geometry.formers.dict().items():       # for keys that are present in the model data (but not all keys in data FiQuS)
             self.data_FiQuS.magnet.geometry.formers.__setattr__(key, value)
         self.data_FiQuS.magnet.geometry.formers.r_ins = model_data.CoilWindings.CCT_straight.former_inner_radiuses  # additional, picked form other places in model data
+        self.data_FiQuS.magnet.geometry.formers.r_outs = model_data.CoilWindings.CCT_straight.former_outer_radiuses  # additional, picked form other places in model data
 
         # air
         self.data_FiQuS.magnet.geometry.air = model_data.Options_FiQuS.cct.geometry.air   # for keys that are present in the model data and in data FiQuS - they are the same
@@ -88,7 +89,6 @@ class BuilderFiQuS:
         self.data_FiQuS.magnet.solve.formers = model_data.Options_FiQuS.cct.solve.formers
         self.data_FiQuS.magnet.solve.air = model_data.Options_FiQuS.cct.solve.air
         self.data_FiQuS.magnet.solve.file_exts = model_data.Options_FiQuS.cct.solve.file_exts
-        self.data_FiQuS.magnet.solve.getdp_exe_path = model_data.Options_FiQuS.cct.solve.getdp_exe_path
         self.data_FiQuS.magnet.solve.pro_template = model_data.Options_FiQuS.cct.solve.pro_template
         self.data_FiQuS.magnet.solve.variables = model_data.Options_FiQuS.cct.solve.variables
         self.data_FiQuS.magnet.solve.volumes = model_data.Options_FiQuS.cct.solve.volumes
