@@ -24,6 +24,6 @@ class DriverFiQuS:
         full_path_output = os.path.join(self.path_folder_FiQuS, output_directory)
 
         # Run model
-        self.MainFiQuS(input_file_path=full_path_input, model_folder=full_path_output)
+        return self.MainFiQuS(input_file_path=full_path_input, model_folder=full_path_output).overall_error
         # return subprocess.call(['py', self.path_exe, model_data_path, outputDirectory])
 
