@@ -6,8 +6,8 @@ from steam_sdk.parsers.ParserYAML import dict_to_yaml
 
 if __name__ == "__main__":
     # path_models = Path.joinpath(Path(__file__).parent.parent.parent, 'C:\\Users\emm\cernbox\SWAN_projects\steam_models\magnets')
-    # path_models = Path.joinpath(Path(__file__).parent.parent.parent, r'E:\Python\steam_models\magnets')
-    path_models = Path.joinpath(Path(__file__).parent.parent.parent, 'tests/builders/model_library/magnets')
+    path_models = Path.joinpath(Path(__file__).parent.parent.parent, r'E:\Python\steam_models\magnets')
+    #path_models = Path.joinpath(Path(__file__).parent.parent.parent, 'tests/builders/model_library/magnets')
     models = [x.parts[-1] for x in Path(path_models).iterdir() if x.is_dir()]
     #models = ['MCBRD']
 
